import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/beauMarko/f7513da95727642a60000c9292d33f96/raw/cssNamedColors';

const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;

const pieArc = arc().innerRadius(0).outerRadius(width);

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvUrl).then(setData);
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX}, ${centerY})`}>
        {data.map((d, i) => (
          <path
            fill={d['RGB hex value']}
            d={pieArc({
              startAngle: (i / data.length) * 2 * Math.PI,
              endAngle:
                ((i + 1) / data.length) * 2 * Math.PI,
            })}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
